@@ -15,9 +15,9 @@ def _change_into_examples_dir(request):
 
 @pytest.mark.usefixtures('_change_into_examples_dir')
 def test_example(default_rules_collection):
-    """example.yml is expected to have 15 match errors inside."""
+    """example.yml is expected to have 16 match errors inside."""
     result = Runner('playbooks/example.yml', rules=default_rules_collection).run()
-    assert len(result) == 15
+    assert len(result) == 16
 
 
 @pytest.mark.parametrize(
@@ -46,3 +46,11 @@ def test_example_custom_module(default_rules_collection):
         'examples/playbooks/custom_module.yml', rules=default_rules_collection
     ).run()
     assert len(result) == 0
+
+
+def test_full_vault(default_rules_collection):
+    """custom_module.yml is expected to pass."""
+    result = Runner(
+        'examples/playbooks/vars/not_decryptable.yml', rules=default_rules_collection
+    ).run()
+    assert len(result) == 0
